==> hlw-core-0.0.2-20250604.075328-42-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/daxx/GetDaxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx.daxx;

import lombok.Data;

import java.util.List;


/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/12/12 9:54
 * @description GetDaxxQueryResultDTO
 */
@Data
public class GetDaxxQueryResultDTO {
    /**
     * 查询唯一标识
     */
    private String rowguid;
    /**
     * 入参区域代码（前端传入的区域代码）
     */
    private String rcqydm;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 产权证号
     */
    private String cqzh;
    /**
     * 不动产类型
     */
    private String bdclx;
    /**
     * 房产证号
     */
    private String fczh;
    /**
     * 权属状态代码
     */
    private String qsztdm;
    /**
     * 权属状态名称
     */
    private String qsztmc;
    /**
     * 项目id
     */
    private String proid;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 定作物用途----dzwyt
     */
    private String ghyt;
    /**
     * 宗地宗海用途----zdzhyt
     */
    private String zdytdm;
    private String zdytmc;
    /**
     * 权利性质
     */
    private String zdzhqlxz;
    private String zdzhqlxzmc;
    /**
     * 定作物面积
     */
    private String dzwmj;
    /**
     * 行政区划数字代码-----xzqhszdm
     */
    private String xzqhdm;
    /**
     * 行政区划数字名称
     */
    private String xzqhszmc;
    /**
     * 街道乡镇代码
     */
    private String jdxzdm;
    /** 宗地宗海面积----zdzhmj*/
    private String zdmj;
    /** 房屋性质*/
    private String fwxz;
    /** 房屋结构*/
    private String fwjg;
    /** 所在层----szc*/
    private String fwszc;
    /** 总层数-----zcs*/
    private String fwzcs;
    /** 物理层---wlc*/
    private String fwsjc;
    /** 房屋类型*/
    private String fwlx;
    /** 所在名义层*/
    private String szmyc;
    /** 层高*/
    private String cg;
    /** 自然幢号---zrzh*/
    private String fwzh;
    /** 房间号---fjh*/
    private String fwfh;
    /** 建筑面积*/
    private String jzmj;
    /** 套内面积---tnmj*/
    private String sctnmj;
    /** 朝向---cx*/
    private String fwcxdm;
    /** 建筑年份*/
    private String jznf;
    /**备注*/
    private String bz;
    /** 产权来源*/
    private String cqly;
    /** 房屋用途名称----fwytmc*/
    private String fwyt;
    /**
     * 房屋用途名称
     */
    private String fwytmc;
    /**发证时间*/
    private String fczfzsj;
    /***/
    private String execmark;
    /**权利人名称*/
    private String qlrmc;
    /** 权利人证件号----qlrzjhm*/
    private String  qlrzjh;
    /** 共有方式*/
    private String gyfs;
    /** 共有比例*/
    private String gybl;
    /** 证书id*/
    private String certid;
    /** 不动产单元编号*/
    private String bdcdybh;
    /**宗地代码*/
    private String zddm;
    /** 权利类型*/
    private String qllx;
    /**权利起始时间*/
    private String qlqssj;
    /** 权利结束时间*/
    private String qljssj;
    /**权利性质*/
    private String qlxz;
    /**宗地权利类型*/
    private String zdqllx;
    /**分摊面积----ftmj*/
    private String scftmj;
    /** 登记类型*/
    private String djlx;
    private String djlxmc;
    /** 登记原因*/
    private String djyy;
    private String djyymc;
    /** 土地使用面积*/
    private String tdsymj;
    /** 套内面积合计*/
    private String tnmjhj;
    /**建筑面积合计*/
    private String jzmjhj;
    /**注销登记时间*/
    private String zxdjsj;
    /** 内网受理编号*/
    private String nwslbh;
    /** 附记*/
    private String fj;
    /**土地使用开始期限------tdsyksqx*/
    private String tdsyqssj;
    /**土地使用结束期限----tdsyjsqx*/
    private String tdsyjssj ;
    /** 土地证号*/
    private String tdzh;
    /** 规划用途代码*/
    private String ghytdm;
    /** 规划用途名称*/
    private String ghytmc;
    /**独用土地面积*/
    private String dytdmj;
    /** 分摊土地面积*/
    private String fttdmj;
    /** 权籍关联代码*/
    private String qjgldm;
    /**
     * 区域名称
     */
    private String qymc;
    /**
     * 权利其他状况
     */
    private String qlqtzk;
    /**居住权信息*/
    private List<DaxxJzqxxDTO> jzqxxList;
    /**抵押信息*/
    private List<DaxxDyxxDTO> dyxxList;
    /**查封信息*/
    private List<DaxxCfxxDTO> cfxxList;
    /**异议信息*/
    private List<DaxxYyxxDTO> yyxxList;
    /**预告信息*/
    private List<DaxxYgxxDTO> ygxxList;
    /**锁定信息*/
    private List<DaxxSdxxDTO> sdxxList;
    /**冻结信息*/
    private List<DaxxDjxxDTO> djxxList;
    /**权利人*/
    private List<DaxxQlrxxDTO> qlrList;
}

==> hlw-core-0.0.2-20250702.125058-77-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/daxx/GetDaxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx.daxx;

import lombok.Data;

import java.util.List;


/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/12/12 9:54
 * @description GetDaxxQueryResultDTO
 */
@Data
public class GetDaxxQueryResultDTO {
    /**
     * 查询唯一标识
     */
    private String rowguid;
    /**
     * 入参区域代码（前端传入的区域代码）
     */
    private String rcqydm;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 产权证号
     */
    private String cqzh;
    /**
     * 不动产类型
     */
    private String bdclx;
    /**
     * 房产证号
     */
    private String fczh;
    /**
     * 权属状态代码
     */
    private String qsztdm;
    /**
     * 权属状态名称
     */
    private String qsztmc;
    /**
     * 项目id
     */
    private String proid;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 定作物用途----dzwyt
     */
    private String ghyt;
    /**
     * 宗地宗海用途----zdzhyt
     */
    private String zdytdm;
    private String zdytmc;
    /**
     * 权利性质
     */
    private String zdzhqlxz;
    private String zdzhqlxzmc;
    /**
     * 定作物面积
     */
    private String dzwmj;
    /**
     * 行政区划数字代码-----xzqhszdm
     */
    private String qydm;
    /**
     * 行政区划数字名称
     */
    private String xzqhszmc;
    /**
     * 街道乡镇代码
     */
    private String jdxzdm;
    /** 宗地宗海面积----zdzhmj*/
    private String zdmj;
    /** 房屋性质*/
    private String fwxz;
    /** 房屋结构*/
    private String fwjg;
    /** 所在层----szc*/
    private String fwszc;
    /** 总层数-----zcs*/
    private String fwzcs;
    /** 物理层---wlc*/
    private String fwsjc;
    /** 房屋类型*/
    private String fwlx;
    /** 所在名义层*/
    private String szmyc;
    /** 层高*/
    private String cg;
    /** 自然幢号---zrzh*/
    private String fwzh;
    /** 房间号---fjh*/
    private String fwfh;
    /** 建筑面积*/
    private String jzmj;
    /** 套内面积---tnmj*/
    private String sctnmj;
    /** 朝向---cx*/
    private String fwcxdm;
    /** 建筑年份*/
    private String jznf;
    /**备注*/
    private String bz;
    /** 产权来源*/
    private String cqly;
    /** 房屋用途名称----fwytmc*/
    private String fwyt;
    /**
     * 房屋用途名称
     */
    private String fwytmc;
    /**发证时间*/
    private String fczfzsj;
    /***/
    private String execmark;
    /**权利人名称*/
    private String qlrmc;
    /** 权利人证件号----qlrzjhm*/
    private String  qlrzjh;
    /** 共有方式*/
    private String gyfs;
    /** 共有比例*/
    private String gybl;
    /** 证书id*/
    private String certid;
    /** 不动产单元编号*/
    private String bdcdybh;
    /**宗地代码*/
    private String zddm;
    /** 权利类型*/
    private String qllx;
    /**权利起始时间*/
    private String qlqssj;
    /** 权利结束时间*/
    private String qljssj;
    /**权利性质*/
    private String qlxz;
    /**宗地权利类型*/
    private String zdqllx;
    /**分摊面积----ftmj*/
    private String scftmj;
    /** 登记类型*/
    private String djlx;
    private String djlxmc;
    /** 登记原因*/
    private String djyy;
    private String djyymc;
    /** 土地使用面积*/
    private String tdsymj;
    /** 套内面积合计*/
    private String tnmjhj;
    /**建筑面积合计*/
    private String jzmjhj;
    /**注销登记时间*/
    private String zxdjsj;
    /** 内网受理编号*/
    private String nwslbh;
    /** 附记*/
    private String fj;
    /**土地使用开始期限------tdsyksqx*/
    private String tdsyqssj;
    /**土地使用结束期限----tdsyjsqx*/
    private String tdsyjssj ;
    /** 土地证号*/
    private String tdzh;
    /** 规划用途代码*/
    private String ghytdm;
    /** 规划用途名称*/
    private String ghytmc;
    /**独用土地面积*/
    private String dytdmj;
    /** 分摊土地面积*/
    private String fttdmj;
    /** 权籍关联代码*/
    private String qjgldm;
    /**
     * 区域名称
     */
    private String qymc;
    /**
     * 权利其他状况
     */
    private String qlqtzk;
    /**居住权信息*/
    private List<DaxxJzqxxDTO> jzqxxList;
    /**抵押信息*/
    private List<DaxxDyxxDTO> dyxxList;
    /**查封信息*/
    private List<DaxxCfxxDTO> cfxxList;
    /**异议信息*/
    private List<DaxxYyxxDTO> yyxxList;
    /**预告信息*/
    private List<DaxxYgxxDTO> ygxxList;
    /**锁定信息*/
    private List<DaxxSdxxDTO> sdxxList;
    /**冻结信息*/
    private List<DaxxDjxxDTO> djxxList;
    /**权利人*/
    private List<DaxxQlrxxDTO> qlrList;
}
